==> openGion8.2.0.3_src.zip: uap/webapps/gf/src/org/opengion/hayabusa/db/Query.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

import java.sql.Connection;									// 6.3.6.1 (2015/08/28)

import org.opengion.hayabusa.resource.ResourceManager;
import org.opengion.fukurou.util.ErrorMessage;

/**
 * ステートメント文を execute() する事により,データベースを検索した結果を DBTableModel に
 * 割り当てるインターフェースです。
 * 実際にこのインターフェースを継承したクラスでは、データベース以外に
 * フラットファイルやXMLデータなどを読み込んで DBTableModel を作成させる
 * 様な実装クラスを作成することができます。
 *
 * @og.group データ表示
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface Query {
	/**
	 * Connectionオブジェクトを外部から設定します。
	 *
	 * 通常は、Transaction と 接続先(DBID) を使用して作成した Connection を渡します。
	 * このクラスでは、Connection の close() や、ConnectionFactory への返却なども
	 * 行いません。それらは、外部処理(通常は、Transactionオブジェクト)で行います。
	 *
	 * Connection には、null は登録できません。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) 新規追加
	 *
	 * @param	conn	Connectionオブジェクト
	 */
	void setConnection( final Connection conn ) ;

	/**
	 * ステートメント文字列をセットします。
	 *
	 * @param   statement ステートメント文字列
	 *
	 */
	void setStatement( String statement ) ;

	/**
	 * ステートメント文字列を取り出します。
	 *
	 * @return  ステートメント文字列
	 *
	 */
	String getStatement();

	/**
	 * ステートメント文字列(UPDATE,INSERT)をセットします。
	 *
	 * @og.rev 7.2.9.1 (2020/10/23) TableUpdateParamTag のマージ(UPDATE,INSERT)対応
	 * @og.rev 7.4.1.0 (2021/04/23) sqlType="MERGE" 時のみ有効で、where 条件で存在すれば何もしない
	 *
	 * @param   update UPDATEステートメント文字列
	 * @param   insert INSERTステートメント文字列
	 * @param   select SELECTステートメント文字列(あれば何もしない、なければINSERT処理の判定用)
	 */
//	void setMergeStatement( String update, String insert ) ;
	void setMergeStatement( String update, String insert , final String select );

	/**
	 * ステートメント文字列(UPDATE,INSERT,SELECT)を取り出します。
	 *
	 * @og.rev 7.2.9.1 (2020/10/23) TableUpdateParamTag のマージ(UPDATE,INSERT)対応
	 *
	 * @return  ステートメント文字列の配列(UPDATE,INSERTの順番)
	 *
	 */
	String[] getMergeStatement();

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は, #execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery や
	 * { call xxxx( ?,?,? ) } などの CallableStatement の ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 6.1.1.0 (2015/01/17) 引数配列を可変引数にして、execute() を含めて定義します。
	 *
	 * @param   args オブジェクトの引数配列
	 */
	void execute( String... args ) ;			// 6.1.1.0 (2015/01/17) refactoring

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は, #execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) 新規追加
	 *
	 * @param   keys オブジェクトのキー配列
	 * @param   args オブジェクトの引数配列
	 */
	void execute( final String[] keys, final String... args ) ;			// 6.1.1.0 (2015/01/17) refactoring

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は, #execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) 引数をすべて受け取って実行するメソッドを標準メソッドとして追加
	 *
	 * @param	names		カラム名(CSV形式)
	 * @param	dbArrayType	アレイタイプ名称
	 * @param	sysArg		DBSysArg配列
	 * @param	userArg		DBUserArg配列
	 */
	void execute( final String names,final String dbArrayType,
					final DBSysArg[] sysArg,final DBUserArg[] userArg ) ;

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は, #execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * [カラム名] 部分の引数を、DBTableModelから順番にセットしていきます。
	 *
	 * @param   rowNo 選択された行番号配列(登録する対象行)
	 * @param   table DBTableModelオブジェクト(登録する元データ)
	 */
	void execute( final int[] rowNo, final DBTableModel table ) ;

	/**
	 * クエリーの実行結果を返します。
	 * クエリーが失敗した場合や,CallableStatement の呼び出し等で実行件数が明確でない
	 * 場合は, -1 が返されます。
	 *
	 * @return	クエリーの実行件数
	 */
	int getExecuteCount() ;

	/**
	 * 実行結果の DBTableModel を返します。
	 *
	 * @return  DBTableModelオブジェクト
	 */
	DBTableModel getDBTableModel() ;

	/**
	 * データベースの最大検索件数を返します。
	 * データベース自体の検索は,指定されたSQLの全件を検索しますが,
	 * DBTableModelのデータとして登録する最大件数をこの値に設定します。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @return  最大検索件数
	 */
	int getMaxRowCount() ;

	/**
	 * データベースの最大検索件数をセットします。
	 * データベース自体の検索は,指定されたSQLの全件を検索しますが,
	 * DBTableModelのデータとして登録する最大件数をこの値に設定します。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @param   maxRowCount 最大検索件数
	 */
	void setMaxRowCount( int maxRowCount ) ;

	/**
	 * データベースの検索スキップ件数を返します。
	 * データベース自体の検索は,指定されたSQLの全件を検索しますが,
	 * DBTableModelのデータとしては、スキップ件数分は登録されません。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @return  最大検索件数
	 */
	int getSkipRowCount();

	/**
	 * データベースの検索スキップ件数をセットします。
	 * データベース自体の検索は,指定されたSQLの全件を検索しますが,
	 * DBTableModelのデータとしては、スキップ件数分は登録されません。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @param   skipRowCount スキップ件数
	 */
	void setSkipRowCount( int skipRowCount );

	/**
	 * アップデートフラグを取得します。
	 * これは、Query で更新処理の SQL 文を実行したときに true にセットされます。
	 * 更新処理が実行：true / 検索処理のみ：false を取得できます。
	 *
	 * @og.rev 2.1.2.3 (2002/12/02) データベース更新時に、更新フラグをセットするように変更
	 * @og.rev 4.0.0.0 (2007/07/20) メソッド名変更( getUpdateFlag() ⇒ isUpdate() )
	 *
	 * @return	 アップデートされたかどうか( 更新処理：true / 検索処理：false )
	 */
	boolean isUpdate() ;

	/**
	 * リソースマネージャーをセットします。
	 * これは、言語(ロケール)に応じた DBColumn をあらかじめ設定しておく為に
	 * 必要です。
	 * リソースマネージャーが設定されていない、または、所定のキーの DBColumn が
	 * リソースに存在しない場合は、内部で DBColumn オブジェクトを作成します。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) lang ⇒ ResourceManager へ変更
	 *
	 * @param  resource リソースマネージャー
	 */
	void setResourceManager( ResourceManager resource ) ;

	/**
	 * エラーコード を取得します。
	 * エラーコード は、ErrorMessage クラスで規定されているコードです。
	 *
	 * @return   エラーコード
	 */
	int getErrorCode() ;

	/**
	 * エラーメッセージオブジェクト を取得します。
	 *
	 * @return   エラーメッセージオブジェクト
	 */
	ErrorMessage getErrorMessage() ;

	/**
	 * 編集設定オブジェクトをセットします。
	 *
	 * @og.rev 5.3.6.0 (2011/06/01) 新規追加
	 *
	 * @param config 編集設定オブジェクト
	 */
	void setEditConfig( final DBEditConfig config );
}

==> openGion8.5.2.0_src.zip: uap/webapps/gf/src/org/opengion/hayabusa/db/Query.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

import java.sql.Connection;									// 6.3.6.1 (2015/08/28)

import org.opengion.hayabusa.resource.ResourceManager;
import org.opengion.fukurou.util.ErrorMessage;

/**
 * ステートメント文を execute() する事により、データベースを検索した結果を DBTableModel に
 * 割り当てるインターフェースです。
 * 実際にこのインターフェースを継承したクラスでは、データベース以外に
 * フラットファイルやXMLデータなどを読み込んで DBTableModel を作成させる
 * 様な実装クラスを作成することができます。
 *
 * @og.group データ表示
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface Query {
	/**
	 * Connectionオブジェクトを外部から設定します。
	 *
	 * 通常は、Transaction と 接続先(DBID) を使用して作成した Connection を渡します。
	 * このクラスでは、Connection の close() や、ConnectionFactory への返却なども
	 * 行いません。それらは、外部処理(通常は、Transactionオブジェクト)で行います。
	 *
	 * Connection には、null は登録できません。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) 新規追加
	 *
	 * @param	conn	Connectionオブジェクト
	 */
	void setConnection( final Connection conn ) ;

	/**
	 * ステートメント文字列をセットします。
	 *
	 * @param   statement ステートメント文字列
	 *
	 */
	void setStatement( String statement ) ;

	/**
	 * ステートメント文字列を取り出します。
	 *
	 * @return  ステートメント文字列
	 *
	 */
	String getStatement();

	/**
	 * ステートメント文字列(UPDATE,INSERT)をセットします。
	 *
	 * @og.rev 7.2.9.1 (2020/10/23) TableUpdateParamTag のマージ(UPDATE,INSERT)対応
	 * @og.rev 7.4.1.0 (2021/04/23) sqlType="MERGE" 時のみ有効で、where 条件で存在すれば何もしない
	 *
	 * @param   update UPDATEステートメント文字列
	 * @param   insert INSERTステートメント文字列
	 * @param   select SELECTステートメント文字列(あれば何もしない、なければINSERT処理の判定用)
	 */
//	void setMergeStatement( String update, String insert ) ;
	void setMergeStatement( String update, String insert , final String select );

	/**
	 * ステートメント文字列(UPDATE,INSERT,SELECT)を取り出します。
	 *
	 * @og.rev 7.2.9.1 (2020/10/23) TableUpdateParamTag のマージ(UPDATE,INSERT)対応
	 *
	 * @return  ステートメント文字列の配列(UPDATE,INSERTの順番)
	 *
	 */
	String[] getMergeStatement();

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は、#execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery や
	 * { call xxxx( ?,?,? ) } などの CallableStatement の ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 6.1.1.0 (2015/01/17) 引数配列を可変引数にして、execute() を含めて定義します。
	 *
	 * @param   args オブジェクトの引数配列
	 */
	void execute( String... args ) ;			// 6.1.1.0 (2015/01/17) refactoring

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は、#execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) 新規追加
	 *
	 * @param   keys オブジェクトのキー配列
	 * @param   args オブジェクトの引数配列
	 */
	void execute( final String[] keys, final String... args ) ;			// 6.1.1.0 (2015/01/17) refactoring

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は、#execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * ? 部分の引数を
	 * 順番にセットしていきます。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) 引数をすべて受け取って実行するメソッドを標準メソッドとして追加
	 *
	 * @param	names		カラム名(CSV形式)
	 * @param	dbArrayType	アレイタイプ名称
	 * @param	sysArg		DBSysArg配列
	 * @param	userArg		DBUserArg配列
	 */
	void execute( final String names,final String dbArrayType,
					final DBSysArg[] sysArg,final DBUserArg[] userArg ) ;

	/**
	 * 引数配列付のクエリーを実行します。
	 * 処理自体は、#execute() と同様に、各サブクラスの実装に依存します。
	 * これは、PreparedQuery で使用する引数を配列でセットするものです。
	 * select * from emp where deptno = ? and job = ? などの PreparedQuery の
	 * [カラム名] 部分の引数を、DBTableModelから順番にセットしていきます。
	 *
	 * @param   rowNo 選択された行番号配列(登録する対象行)
	 * @param   table DBTableModelオブジェクト(登録する元データ)
	 */
	void execute( final int[] rowNo, final DBTableModel table ) ;

	/**
	 * クエリーの実行結果を返します。
	 * クエリーが失敗した場合や、CallableStatement の呼び出し等で実行件数が明確でない
	 * 場合は、-1 が返されます。
	 *
	 * @return	クエリーの実行件数
	 */
	int getExecuteCount() ;

	/**
	 * 実行結果の DBTableModel を返します。
	 *
	 * @return  DBTableModelオブジェクト
	 */
	DBTableModel getDBTableModel() ;

	/**
	 * データベースの最大検索件数を返します。
	 * データベース自体の検索は、指定されたSQLの全件を検索しますが、
	 * DBTableModelのデータとして登録する最大件数をこの値に設定します。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @return  最大検索件数
	 */
	int getMaxRowCount() ;

	/**
	 * データベースの最大検索件数をセットします。
	 * データベース自体の検索は、指定されたSQLの全件を検索しますが、
	 * DBTableModelのデータとして登録する最大件数をこの値に設定します。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @param   maxRowCount 最大検索件数
	 */
	void setMaxRowCount( int maxRowCount ) ;

	/**
	 * データベースの検索スキップ件数を返します。
	 * データベース自体の検索は、指定されたSQLの全件を検索しますが、
	 * DBTableModelのデータとしては、スキップ件数分は登録されません。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @return  最大検索件数
	 */
	int getSkipRowCount();

	/**
	 * データベースの検索スキップ件数をセットします。
	 * データベース自体の検索は、指定されたSQLの全件を検索しますが、
	 * DBTableModelのデータとしては、スキップ件数分は登録されません。
	 * サーバーのメモリ資源と応答時間の確保の為です。
	 *
	 * @param   skipRowCount スキップ件数
	 */
	void setSkipRowCount( int skipRowCount );

	/**
	 * アップデートフラグを取得します。
	 * これは、Query で更新処理の SQL 文を実行したときに true にセットされます。
	 * 更新処理が実行：true / 検索処理のみ：false を取得できます。
	 *
	 * @og.rev 2.1.2.3 (2002/12/02) データベース更新時に、更新フラグをセットするように変更
	 * @og.rev 4.0.0.0 (2007/07/20) メソッド名変更( getUpdateFlag() ⇒ isUpdate() )
	 *
	 * @return	 アップデートされたかどうか( 更新処理：true / 検索処理：false )
	 */
	boolean isUpdate() ;

	/**
	 * リソースマネージャーをセットします。
	 * これは、言語(ロケール)に応じた DBColumn をあらかじめ設定しておく為に
	 * 必要です。
	 * リソースマネージャーが設定されていない、または、所定のキーの DBColumn が
	 * リソースに存在しない場合は、内部で DBColumn オブジェクトを作成します。
	 *
	 * @og.rev 4.0.0.0 (2005/01/31) lang ⇒ ResourceManager へ変更
	 *
	 * @param  resource リソースマネージャー
	 */
	void setResourceManager( ResourceManager resource ) ;

	/**
	 * エラーコード を取得します。
	 * エラーコード は、ErrorMessage クラスで規定されているコードです。
	 *
	 * @return   エラーコード
	 */
	int getErrorCode() ;

	/**
	 * エラーメッセージオブジェクト を取得します。
	 *
	 * @return   エラーメッセージオブジェクト
	 */
	ErrorMessage getErrorMessage() ;

	/**
	 * 編集設定オブジェクトをセットします。
	 *
	 * @og.rev 5.3.6.0 (2011/06/01) 新規追加
	 *
	 * @param config 編集設定オブジェクト
	 */
	void setEditConfig( final DBEditConfig config );
}
